==> haskell-wai-extra-3.0.20.0-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.20.0
id: wai-extra-3.0.20.0-3RsqWfyj5YW2l6djskzmjS
key: wai-extra-3.0.20.0-3RsqWfyj5YW2l6djskzmjS
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
abi: 13293e4ec776e3f4b67c5df7b3b64403
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/wai-extra-3.0.20.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/wai-extra-3.0.20.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/wai-extra-3.0.20.0
hs-libraries: HSwai-extra-3.0.20.0-3RsqWfyj5YW2l6djskzmjS
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM time-1.8.0.2
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx directory-1.3.0.2
    transformers-0.5.2.0 blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7
    wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs
    ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    void-0.7.2-KNNEd7XG9bDRysTndgnf2
    stringsearch-0.3.6.6-K30MyFaBEiEDdRa9SPnW19 containers-0.5.10.2
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    word8-0.1.3-CN5TjopM0jqExzuBsYZ0mY
    lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ deepseq-1.4.3.0
    streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4
    unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
    cookie-0.4.2.1-EtHMWPQIghd9pOfnkVb7tc
    vault-0.3.0.7-UMEOtujMAKHj95FR8j5G
    zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am unix-2.7.2.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=f827a1e0ea45c8f4df4af8d8f4f0be53
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=bb3d8fbe7de4d3cc9ed854226de736b7
             time-1.8.0.2=3f789f9c9fc88790a10579b55c2f0b4f
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=ef2cd2ee3956583f4f4dc001b18e6763
             directory-1.3.0.2=f0be8e5bd351f97ab9c9e693d2eba4ad
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
             blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl=a7a58201b1be24d3f9828cceaa002b51
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=8bdb3e32f976a0904554b35642e32260
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=42480b67fee41ad692110e11eaac57c4
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=f9fb05439242cab6e496c322f2a1e33a
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=cbc023a13af0b49e672a5936ee9b18d1
             fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7=33fd215366cb28f701e1bed60ab08620
             wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs=2e0bba0c5c47b618b14507fed08578c8
             ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU=8d42c7012ae6bb1dfca5905fe8a25762
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2ffddbfcc20d0db652f15951a99e02a7
             void-0.7.2-KNNEd7XG9bDRysTndgnf2=17ec282264751cc765759d5ebe13c331
             stringsearch-0.3.6.6-K30MyFaBEiEDdRa9SPnW19=6fad8b18f5a5d3ec2b7c7758d7d2ee3e
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=d31f9783df40d231323e9ab91d44fa81
             word8-0.1.3-CN5TjopM0jqExzuBsYZ0mY=c674ac3552620af97a08fc348e4f8b97
             lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ=33a1580c74fba9f604072e920a7a1dd3
             deepseq-1.4.3.0=15f2832424b38ea5b23f1ebc9071dcc3
             streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4=139b945d83cd25f050add96e3b5ef419
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=f0e3615d16ccc9a099618a4b1bfc9d59
             cookie-0.4.2.1-EtHMWPQIghd9pOfnkVb7tc=9c4fbcfeba2240bc9e13ad7138cf8ab7
             vault-0.3.0.7-UMEOtujMAKHj95FR8j5G=afafae121f3533c2f03b57e8ec81f3e2
             zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB=f9a6b8e404d4e5df9363e7202bb41dfe
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=24e17c277694d424049cb17264b51a8f
             iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am=df6c301c27b8ee75fd2d78b106528925
             unix-2.7.2.2=7af8630098b53e228272ffaea5bacf62
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-extra-3.0.20.0-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.20.0
id: wai-extra-3.0.20.0-BsgGxPimsjqDT3aPQxdXol
key: wai-extra-3.0.20.0-BsgGxPimsjqDT3aPQxdXol
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
abi: bf90b42aacc8b78fc006c9ec6aa3d636
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/wai-extra-3.0.20.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/wai-extra-3.0.20.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/wai-extra-3.0.20.0
hs-libraries: HSwai-extra-3.0.20.0-BsgGxPimsjqDT3aPQxdXol
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM time-1.8.0.2
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx directory-1.3.0.2
    transformers-0.5.2.0 blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7
    wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs
    ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    void-0.7.2-KNNEd7XG9bDRysTndgnf2
    stringsearch-0.3.6.6-K30MyFaBEiEDdRa9SPnW19 containers-0.5.10.2
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    word8-0.1.3-CN5TjopM0jqExzuBsYZ0mY
    lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ deepseq-1.4.3.0
    streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4
    unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
    cookie-0.4.2.1-EtHMWPQIghd9pOfnkVb7tc
    vault-0.3.0.7-UMEOtujMAKHj95FR8j5G
    zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am unix-2.7.2.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=f827a1e0ea45c8f4df4af8d8f4f0be53
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=bb3d8fbe7de4d3cc9ed854226de736b7
             time-1.8.0.2=3f789f9c9fc88790a10579b55c2f0b4f
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=ef2cd2ee3956583f4f4dc001b18e6763
             directory-1.3.0.2=f0be8e5bd351f97ab9c9e693d2eba4ad
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
             blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl=a7a58201b1be24d3f9828cceaa002b51
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=8bdb3e32f976a0904554b35642e32260
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=42480b67fee41ad692110e11eaac57c4
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=f9fb05439242cab6e496c322f2a1e33a
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=cbc023a13af0b49e672a5936ee9b18d1
             fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7=33fd215366cb28f701e1bed60ab08620
             wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs=2e0bba0c5c47b618b14507fed08578c8
             ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU=8d42c7012ae6bb1dfca5905fe8a25762
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2ffddbfcc20d0db652f15951a99e02a7
             void-0.7.2-KNNEd7XG9bDRysTndgnf2=17ec282264751cc765759d5ebe13c331
             stringsearch-0.3.6.6-K30MyFaBEiEDdRa9SPnW19=6fad8b18f5a5d3ec2b7c7758d7d2ee3e
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=d31f9783df40d231323e9ab91d44fa81
             word8-0.1.3-CN5TjopM0jqExzuBsYZ0mY=c674ac3552620af97a08fc348e4f8b97
             lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ=33a1580c74fba9f604072e920a7a1dd3
             deepseq-1.4.3.0=15f2832424b38ea5b23f1ebc9071dcc3
             streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4=139b945d83cd25f050add96e3b5ef419
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=f0e3615d16ccc9a099618a4b1bfc9d59
             cookie-0.4.2.1-EtHMWPQIghd9pOfnkVb7tc=9c4fbcfeba2240bc9e13ad7138cf8ab7
             vault-0.3.0.7-UMEOtujMAKHj95FR8j5G=afafae121f3533c2f03b57e8ec81f3e2
             zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB=f9a6b8e404d4e5df9363e7202bb41dfe
             aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=61053bde0c5cda47d1a123db05d36888
             iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am=df6c301c27b8ee75fd2d78b106528925
             unix-2.7.2.2=7af8630098b53e228272ffaea5bacf62
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
